"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TarballHttpResolver = void 0;

var _core = require("@yarnpkg/core");

var _constants = require("./constants");

class TarballHttpResolver {
  supportsDescriptor(descriptor, opts) {
    if (!_constants.TARBALL_REGEXP.test(descriptor.range)) return false;
    if (_constants.PROTOCOL_REGEXP.test(descriptor.range)) return true;
    return false;
  }

  supportsLocator(locator, opts) {
    if (!_constants.TARBALL_REGEXP.test(locator.reference)) return false;
    if (_constants.PROTOCOL_REGEXP.test(locator.reference)) return true;
    return false;
  }

  shouldPersistResolution(locator, opts) {
    return true;
  }

  bindDescriptor(descriptor, fromLocator, opts) {
    return descriptor;
  }

  getResolutionDependencies(descriptor, opts) {
    return [];
  }

  async getCandidates(descriptor, dependencies, opts) {
    return [_core.structUtils.convertDescriptorToLocator(descriptor)];
  }

  async resolve(locator, opts) {
    if (!opts.fetchOptions) throw new Error(`Assertion failed: This resolver cannot be used unless a fetcher is configured`);
    const packageFetch = await opts.fetchOptions.fetcher.fetch(locator, opts.fetchOptions);
    const manifest = await _core.miscUtils.releaseAfterUseAsync(async () => {
      return await _core.Manifest.find(packageFetch.prefixPath, {
        baseFs: packageFetch.packageFs
      });
    }, packageFetch.releaseFs);
    return { ...locator,
      version: manifest.version || `0.0.0`,
      languageName: opts.project.configuration.get(`defaultLanguageName`),
      linkType: _core.LinkType.HARD,
      dependencies: manifest.dependencies,
      peerDependencies: manifest.peerDependencies,
      dependenciesMeta: manifest.dependenciesMeta,
      peerDependenciesMeta: manifest.peerDependenciesMeta,
      bin: manifest.bin
    };
  }

}

exports.TarballHttpResolver = TarballHttpResolver;